@@ -13,19 +13,19 @@ def _dtype_to_cdf_type(var):
     epoch_regex_1 = re.compile('epoch$')
     epoch_regex_2 = re.compile('epoch_[0-9]+$')
     if epoch_regex_1.match(var.name.lower()) or epoch_regex_2.match(var.name.lower()):
-        return 33, 1 # CDF_EPOCH_TT2000
+        return 33, 1  # CDF_EPOCH_TT2000
 
     if var.dtype == np.int8 or var.dtype == np.int16 or var.dtype == np.int32 or var.dtype == np.int64:
-        return 8, 1 #'CDF_INT8'
+        return 8, 1  # 'CDF_INT8'
     elif var.dtype == np.float64 or var.dtype == np.float32 or var.dtype == np.float16:
-        return 45, 1 #'CDF_DOUBLE'
+        return 45, 1  # 'CDF_DOUBLE'
     elif var.dtype == np.uint8 or var.dtype == np.uint16 or var.dtype == np.uint32 or var.dtype == np.uint64:
-        return 14, 1 #'CDF_UNIT4'
+        return 14, 1  # 'CDF_UNIT4'
     elif var.dtype.type == np.str_:
-        return 51, int(var.dtype.str[2:]) # CDF_CHAR, and the length of the longest string in the numpy array
-    elif var.dtype.type == np.bytes_: # Bytes are usually strings
-        return 51, int(var.dtype.str[2:]) # CDF_CHAR, and the length of the longest string in the numpy array
-    elif var.dtype == np.object: # This commonly means we have multidimensional arrays of strings
+        return 51, int(var.dtype.str[2:])  # CDF_CHAR, and the length of the longest string in the numpy array
+    elif var.dtype.type == np.bytes_:  # Bytes are usually strings
+        return 51, int(var.dtype.str[2:])  # CDF_CHAR, and the length of the longest string in the numpy array
+    elif var.dtype == np.object:  # This commonly means we have multidimensional arrays of strings
         try:
             longest_string = 0
             for x in np.nditer(var.data, flags=['refs_ok']):
@@ -33,7 +33,8 @@ def _dtype_to_cdf_type(var):
                     longest_string = len(str(x))
             return 51, longest_string
         except Exception as e:
-            print(f'NOT SUPPORTED: Data in variable {var.name} has data type {var.dtype}.  Attempting to convert it to strings ran into the error: {str(e)}')
+            print(
+                f'NOT SUPPORTED: Data in variable {var.name} has data type {var.dtype}.  Attempting to convert it to strings ran into the error: {str(e)}')
             return 51, 1
     elif var.dtype.type == np.datetime64:
         return 33, 1
@@ -41,16 +42,17 @@ def _dtype_to_cdf_type(var):
         print(f'NOT SUPPORTED: Data in variable {var.name} has data type of {var.dtype}.')
         return 51, 1
 
+
 def _dtype_to_fillval(dtype):
 
     if dtype == np.int8 or dtype == np.int16 or dtype == np.int32 or dtype == np.int64:
-        return -9223372036854775808 # Default FILLVAL of 'CDF_INT8'
+        return -9223372036854775808  # Default FILLVAL of 'CDF_INT8'
     elif dtype == np.float64 or dtype == np.float32 or dtype == np.float16:
-        return -1e30 #Default FILLVAL of 'CDF_DOUBLE'
+        return -1e30  # Default FILLVAL of 'CDF_DOUBLE'
     elif dtype == np.uint8 or dtype == np.uint16 or dtype == np.uint32 or dtype == np.uint64:
-        return 4294967294 #Default FILLVAL of 'CDF_UNIT4'
+        return 4294967294  # Default FILLVAL of 'CDF_UNIT4'
     elif dtype.type == np.str_:
-        return " " # Default FILLVAL of 'CDF_CHAR'
+        return " "  # Default FILLVAL of 'CDF_CHAR'
     else:
         print(f'Data type of {dtype} not supported')
 
@@ -63,20 +65,24 @@ def _verify_depend_dimensions(dataset, dimension_number, primary_variable_name,
     coordinate_data = np.array(dataset[coordinate_variable_name])
 
     if len(primary_data.shape) != 0 and len(coordinate_data.shape) == 0:
-        print(f'ISTP Compliance Warning: {coordinate_variable_name} is listed as the DEPEND_{dimension_number} for variable {primary_variable_name}, but the dimensions do not match.')
+        print(
+            f'ISTP Compliance Warning: {coordinate_variable_name} is listed as the DEPEND_{dimension_number} for variable {primary_variable_name}, but the dimensions do not match.')
         return False
 
     if len(coordinate_data.shape) != 0 and len(primary_data.shape) == 0:
-        print(f'ISTP Compliance Warning: {coordinate_variable_name} is listed as the DEPEND_{dimension_number} for variable {primary_variable_name}, but the dimensions do not match.')
+        print(
+            f'ISTP Compliance Warning: {coordinate_variable_name} is listed as the DEPEND_{dimension_number} for variable {primary_variable_name}, but the dimensions do not match.')
         return False
 
     if len(coordinate_data.shape) > 2:
-        print(f'ISTP Compliance Warning: {coordinate_variable_name} has too many dimensions to be the DEPEND_{dimension_number} for variable {primary_variable_name}')
+        print(
+            f'ISTP Compliance Warning: {coordinate_variable_name} has too many dimensions to be the DEPEND_{dimension_number} for variable {primary_variable_name}')
         return False
     if len(coordinate_data.shape) == 2:
 
         if primary_data.shape[0] != coordinate_data.shape[0]:
-            print(f'ISTP Compliance Warning: {coordinate_variable_name} is listed as the DEPEND_{dimension_number} for variable {primary_variable_name}, but the Epoch dimensions do not match.')
+            print(
+                f'ISTP Compliance Warning: {coordinate_variable_name} is listed as the DEPEND_{dimension_number} for variable {primary_variable_name}, but the Epoch dimensions do not match.')
             return False
 
     if len(primary_data.shape) <= dimension_number:
@@ -84,7 +90,8 @@ def _verify_depend_dimensions(dataset, dimension_number, primary_variable_name,
         return False
 
     if primary_data.shape[dimension_number] != coordinate_data.shape[-1]:
-        print(f'ISTP Compliance Warning: {coordinate_variable_name} is listed as the DEPEND_{dimension_number} for variable {primary_variable_name}, but the dimensions do not match.')
+        print(
+            f'ISTP Compliance Warning: {coordinate_variable_name} is listed as the DEPEND_{dimension_number} for variable {primary_variable_name}, but the dimensions do not match.')
         return False
 
     return True
@@ -111,12 +118,14 @@ def _dimension_checker(dataset):
 
             # Determine the variable type (data, support_data, metadata, ignore_data)
             if 'VAR_TYPE' not in dataset[var].attrs:
-                print(f'ISTP Compliance Warning: Variable {var} does not have an attribute VAR_TYPE to describe the variable.  Attributes must be either data, support_data, metadata, or ignore_data.')
+                print(
+                    f'ISTP Compliance Warning: Variable {var} does not have an attribute VAR_TYPE to describe the variable.  Attributes must be either data, support_data, metadata, or ignore_data.')
                 var_type = None
             else:
                 var_type = dataset[var].attrs['VAR_TYPE']
                 if var_type.lower() not in ('data', 'support_data', 'metadata', 'ignore_data'):
-                    print(f'ISTP Compliance Warning: Variable {var} attribute VAR_TYPE is not set to either data, support_data, metadata, or ignore_data.')
+                    print(
+                        f'ISTP Compliance Warning: Variable {var} attribute VAR_TYPE is not set to either data, support_data, metadata, or ignore_data.')
                     var_type = None
 
             # Determine ISTP compliant variables
@@ -127,18 +136,20 @@ def _dimension_checker(dataset):
                         if _verify_depend_dimensions(dataset, int(att[-1]), var, depend_i):
                             istp_depend_dimension_list.append(dataset[var].attrs[att])
                     else:
-                        print(f'ISTP Compliance Warning: variable {var} listed {dataset[var].attrs[att]} as its {att}.  However, it was not found in the dataset.')
+                        print(
+                            f'ISTP Compliance Warning: variable {var} listed {dataset[var].attrs[att]} as its {att}.  However, it was not found in the dataset.')
 
             # Determine potential dimension (non-epoch) variables
             potential_depend_dims = dataset[var].dims[1:]
             i = 1
             for d in potential_depend_dims:
                 depend_dimension_list.append(d)
-                if d not in dataset: # Check if the dimension is in the coordinates themselves
+                if d not in dataset:  # Check if the dimension is in the coordinates themselves
                     if var_type is not None and var_type.lower() == 'data':
                         if f'DEPEND_{i}' not in dataset[var].attrs:
-                            print(f'ISTP Compliance Warning: variable {var} contains a dimension {d} that is not defined in xarray.  '
-                                  f'Specify one of the other xarray DataArrays as the DEPEND_{i} attribute.')
+                            print(
+                                f'ISTP Compliance Warning: variable {var} contains a dimension {d} that is not defined in xarray.  '
+                                f'Specify one of the other xarray DataArrays as the DEPEND_{i} attribute.')
                 i += 1
 
     depend_dimension_list = list(set(depend_dimension_list))
@@ -163,6 +174,7 @@ def _recheck_dimensions_after_epoch_checker(dataset, time_varying_dimensions, di
 
     return depend_dimension_list
 
+
 def _epoch_checker(dataset, dim_vars):
 
     # This holds the list of epoch variables
@@ -207,12 +219,14 @@ def _epoch_checker(dataset, dim_vars):
                     depend_0_list.append(potential_depend_0)
                     time_varying_dimensions.append(var)
                 else:
-                    print(f'ISTP Compliance Warning: variable {var} contained a "record" dimension {potential_depend_0}, but they have different dimensions.')
+                    print(
+                        f'ISTP Compliance Warning: variable {var} contained a "record" dimension {potential_depend_0}, but they have different dimensions.')
             elif epoch_regex_1.match(var.lower()) or epoch_regex_2.match(var.lower()):
                 depend_0_list.append(potential_depend_0)
                 time_varying_dimensions.append(var)
             else:
-                print(f'ISTP Compliance Warning: variable {var} contained an "record" dimension {potential_depend_0}, but it was not found in the data set.')
+                print(
+                    f'ISTP Compliance Warning: variable {var} contained an "record" dimension {potential_depend_0}, but it was not found in the data set.')
 
     depend_0_list = list(set(depend_0_list))
 
@@ -222,7 +236,7 @@ def _epoch_checker(dataset, dim_vars):
     epoch_found = False
     for d in depend_0_list:
         if d.lower().startswith('epoch'):
-            epoch_found=True
+            epoch_found = True
 
     if not epoch_found:
         print(f'ISTP Compliance Warning: There is no variable named Epoch.  Epoch is the required name of a DEPEND_0 attribute.')
@@ -242,12 +256,12 @@ def _add_depend_variables_to_dataset(dataset, dim_vars, depend_0_vars, time_vary
             if var in time_varying_dimensions:
                 if 'DEPEND_0' not in dataset[var].attrs:
                     depend_0 = dataset[var].dims[0]
-                    #if 'VAR_TYPE' in dataset[var].attrs and dataset[var].attrs['VAR_TYPE'].lower() == 'data':
+                    # if 'VAR_TYPE' in dataset[var].attrs and dataset[var].attrs['VAR_TYPE'].lower() == 'data':
                     #    depend_0 = first_dim_name
-                    #elif 'VAR_TYPE' in dataset[var].attrs and dataset[var].attrs['VAR_TYPE'].lower() == 'support_data' and len(
+                    # elif 'VAR_TYPE' in dataset[var].attrs and dataset[var].attrs['VAR_TYPE'].lower() == 'support_data' and len(
                     #        dataset[var].dims) > 1:
                     #    depend_0 = first_dim_name
-                    #else:
+                    # else:
                     #    depend_0 = None
 
                     if depend_0 is not None and depend_0 in depend_0_vars and var != depend_0:
@@ -338,7 +352,8 @@ def _variable_attribute_checker(dataset, epoch_list):
                         if d[var].attrs['LABL_PTR_1'] in dataset or d[var].attrs['LABL_PTR_1'] in dataset.coords:
                             pass
                         else:
-                            print(f'ISTP Compliance Warning: LABL_PTR_1 attribute for variable {var} does not point to an existing variable.')
+                            print(
+                                f'ISTP Compliance Warning: LABL_PTR_1 attribute for variable {var} does not point to an existing variable.')
                     else:
                         print(f'ISTP Compliance Warning: LABLAXIS or LABL_PTR_1 attribute is required for variable {var}')
 
@@ -348,7 +363,8 @@ def _variable_attribute_checker(dataset, epoch_list):
                         print(f'ISTP Compliance Warning: UNITS or UNIT_PTR attribute is required for variable {var}')
                     else:
                         if d[var].attrs['UNIT_PTR'] not in dataset:
-                            print(f'ISTP Compliance Warning: UNIT_PTR attribute for variable {var} does not point to an existing variable.')
+                            print(
+                                f'ISTP Compliance Warning: UNIT_PTR attribute for variable {var} does not point to an existing variable.')
 
             if 'VALIDMIN' not in d[var].attrs:
                 if var_type.lower() == 'data':
@@ -427,7 +443,7 @@ def _unixtime_to_tt2000(unixtime_data):
                              dt.hour,
                              dt.minute,
                              dt.second,
-                             int(dt.microsecond/1000),
+                             int(dt.microsecond / 1000),
                              int(dt.microsecond % 1000),
                              0]
             converted_data = cdfepoch.compute(dt_to_convert)
@@ -449,14 +465,15 @@ def _datetime_to_tt2000(datetime_data):
                          dd.hour,
                          dd.minute,
                          dd.second,
-                         int(dd.microsecond/1000),
+                         int(dd.microsecond / 1000),
                          int(dd.microsecond % 1000),
                          0]
         np.append(tt2000_data, cdfepoch.compute(dd_to_convert))
     return tt2000_data
 
 
-def xarray_to_cdf(xarray_dataset, file_name, from_unixtime=False, from_datetime=False, istp=True, record_dimensions=[], compression=0):
+def xarray_to_cdf(xarray_dataset, file_name, from_unixtime=False, from_datetime=False,
+                  istp=True, record_dimensions=[], compression=0):
     """
     This function converts XArray Dataset objects into CDF files.
 
@@ -655,7 +672,7 @@ def xarray_to_cdf(xarray_dataset, file_name, from_unixtime=False, from_datetime=
                     elif from_datetime:
                         var_data = _datetime_to_tt2000(d[var].data)
                 elif cdf_data_type == 33:
-                    unixtime_from_datetime64 = d[var].data.astype('int64')/1000000000.0
+                    unixtime_from_datetime64 = d[var].data.astype('int64') / 1000000000.0
                     var_data = _unixtime_to_tt2000(unixtime_from_datetime64)
 
             x.write_var(var_spec, var_attrs=var_att_dict, var_data=var_data)
